@@ -1,4 +1,4 @@
-from .idl import parse, parse_as_dict, validate
+from .idl import parse, raw_parse, validate
 from .parser import Parser as WebIDLParser
 from .visitor import Visitor as WebIDLVisitor
 
@@ -6,6 +6,6 @@ __all__ = (
     'WebIDLParser',
     'WebIDLVisitor',
     'parse',
-    'parse_as_dict',
+    'raw_parse',
     'validate',
 )
